#
# ERIS 2009
#
# This script produces a UV dataset with UVCON and plots the visibilities per baseline
# it alternates the dataset by including a secound source and plots the visibilities again.
#
# comments to Hans-Rainer Kloeckner 
# hrk@astro.ox.ac.uk
#
from time import sleep
#
import AIPS
from AIPSTask import AIPSTask
from AIPSTV import AIPSTV
from AIPSData import AIPSUVData, AIPSImage


AIPS.userno = 456                          # set the aips user number

AIPS.log    = open('./TUT2.log','w')       # define the log file

# Here produce the UVfits file
uvcon            = AIPSTask('UVCON')
uvcon.infile     = 'AIPSTARS:VLA-D_UVCON'
uvcon.outname    = 'SIM'
uvcon.outseq     = 1
uvcon.smodel[1:]  = [1]
uvcon.aparm[1]   = 1.667                  # Frequency of lowest frequency channel, GHz
uvcon.aparm[2]   = 0                      
uvcon.aparm[3]   = 60                     # source declination
uvcon.aparm[4]   = -1                     # Min hour angle, hours, related to the array centre
uvcon.aparm[5]   = 1                      # Max hour angle, hours
uvcon.aparm[6]   = 0                      # Min antenna elevation, deg
uvcon.aparm[7]   = 60                     # Integration time per visibility point, sec
uvcon.aparm[8]   = 0.1                    # Bandwidth(Increment) of frequency channel, MHz
uvcon.aparm[9]   = 1                      # number of channels      
uvcon.do3dimag   = 1
uvcon.go()
#
uvdata = AIPSUVData('SIM','UVCON', 1, 1)
#
vplot              = AIPSTask('vplot')
vplot.indata       = uvdata
vplot.bparm[1:]    = [12,1]
vplot.antennas[1]  = 1
vplot.baseline[1:] = [2,3,4,5,6,7,8,9,10,11]
vplot.nplots       = 10
vplot.dotv         = -1
vplot.go()
#
# Plot the PL table of vplot
#
lwpla          = AIPSTask('lwpla')
lwpla.indata   = uvdata
lwpla.plver    = 1
lwpla.invers   = 1
lwpla.dparm[5] = 1
lwpla.lpen     = 1
lwpla.docolor  = -1
lwpla.outfile  = './'+'PT_TUT2_1_1JY.PS'
lwpla.go()
#
# Deletes all the PL tables
uvdata.zap_table('PL', -1)
#
uvmod            = AIPSTask('UVMOD')
uvmod.indata     = uvdata
uvmod.ngauss     = 2
print '\nA BIG array',uvmod.fpos,'\n\n'
sleep(3)
uvmod.ctype[1]      = 0
uvmod.fmax[1]       = 1
uvmod.fpos[1][1:]   = [1800,1800]
uvmod.factor        = 1
uvmod.go()
#
uvdata2 = AIPSUVData('SIM','UVMOD', 1, 1)
#
# Produce baseline plots of the modified UVdataset
#
vplot              = AIPSTask('vplot')
vplot.indata       = uvdata2
vplot.bparm[1:]    = [12,1]
vplot.antennas[1]  = 1
vplot.baseline[1:] = [2,3,4,5,6,7,8,9,10,11]
vplot.nplots       = 10
vplot.dotv         = -1
vplot.go()
#
# Plot the PL table of vplot
#
lwpla          = AIPSTask('lwpla')
lwpla.indata   = uvdata2
lwpla.plver    = 1
lwpla.invers   = 1
lwpla.dparm[5] = 1
lwpla.lpen     = 1
lwpla.docolor  = -1
lwpla.outfile  = './'+'PT_TUT2_2_1JY.PS'
lwpla.go()
#
#
print '\n\n----------------------------------------------------\n\n'
print '\n\n\n\n-- Header information of simulated UV dataset --\n'
print 'uvdata.header gives:\n',uvdata.header,'\n'
print 'uvdata.header.keys() provide the keyword in the header:\n', uvdata.header.keys(),'\n'
print 'uvdata.header.has_keys() logical feedback is keyword exsists:\n', uvdata.header.has_key('HRK'),'\n'
print 'uvdata.header[\'ctype\'] gives:\n',uvdata.header['ctype'],'\n\n'
print '\n\n----------------------------------------------------\n\n'
#
# deletes the first database!
#
uvdata.zap()
#


