#
# ERIS 2009
#
# This example shows how to access the antenna table (AM) of a file
# and how to read out visibilities  
#
# comments to Hans-Rainer Kloeckner 
# hrk@astro.ox.ac.uk
#
from time import sleep
from math import atan2,pi,sqrt
#
import AIPS
from AIPSTask import AIPSTask
from AIPSTV import AIPSTV
from AIPSData import AIPSUVData, AIPSImage
#
from Wizardry.AIPSData import AIPSUVData as AIPSDataVIS
#


AIPS.userno = 456                          # set the aips user number

AIPS.log    = open('./TUT3.log','w')       # define the log file

# Define a datafile for convenience 
data = ['SIM','UVMOD', 1, 1]
#
#
# Use AIPS task to print antenna table  (AN)
#
#
uvdata2 = AIPSUVData(data[0],data[1],data[2],data[3])
#
prtan         = AIPSTask('prtan')
prtan.indata  = uvdata2
prtan.docrt   = -1
prtan.outprint = './'+'PT_TUT3_ANT_POSITIONS'
prtan.go() 
#
# Use PT to print the table content of the AN table
#
antab  = uvdata2.table('AN',1)

x,y,z = [],[],[]
for row in antab:
    # print row                          # uncommend to see what you are doing in each row
    x.append(row.stabxyz[0])
    y.append(row.stabxyz[1])
    z.append(row.stabxyz[2])

print '\n\n Antenna positions X Y Z\n\n'
for i in range(len(x)):
    print x[i],y[i],z[i]


sleep(5)

# Define the baseline to plot
basel = [1,9]
IF    = 0
chan  = 0
st    = 0
#
#
uvdis         = []
re,im,weight  = [],[],[]
time,phas,amp = [],[],[]
#
visdata = AIPSDataVIS(data[0],data[1],data[2],data[3])
for visibility in visdata:
    if visibility.baseline[0] == basel[0] and visibility.baseline[1] == basel[1]:
        # 
        u = visibility.uvw[0]
        v = visibility.uvw[1]
        w = visibility.uvw[2]
        uvdis.append(sqrt(u**2+v**2+w**2))
        #
        re.append(visibility.visibility[IF,chan,st,0])
        im.append(visibility.visibility[IF,chan,st,1])
        weight.append(visibility.visibility[IF,chan,st,2])
        #
        sim = visibility.visibility[IF,chan,st,1]
        sre = visibility.visibility[IF,chan,st,0]
        time.append(visibility.time)
        phas.append((360./(2*pi)*atan2(sim, sre)))
        amp.append(sqrt(sre**2+sim**2))


try:
    import pylab
except ImportError:
    print '\nSorry not pylab installed, so can not make a nice plot'
    print 'but poduced a data file.\n'
    file  = open('PT_TUT3_BL_AMP_TIME.data','w')
    #print >> file, 'Basline ',basel,' time versus amplitude'
    for i in range(len(amp)):
        print >>file, time[i], amp[i]
    file.close()
else:
    import pylab
    pylab.scatter(time,amp)
    pylab.show()
